import request from '@/utils/request'

// 内部订单列表
export function orderList(params) {
  return request({
    url: `/sip/order/list`,
    method: 'get',
    params: params
  })
}
// 内部订单删除(明细删除)
export function delOrder(data) {
  return request({
    url: `/sip/order/remove`,
    method: 'DELETE',
    data: data
  })
}
// 新增查询订单
export function searchList(params) {
  return request({
    url: `/sip/order/pu/list`,
    method: 'get',
    params: params
  })
}
// 内部订单价格修改
export function editOrder(data) {
  return request({
    url: `/sip/order`,
    method: 'put',
    data: data
  })
}
// 内部订单价格模板下载
export function mbDownload(params) {
  return request({
    url: `/sip/order/exportTemplate`,
    method: 'get',
    params: params,
    responseType: 'blob'
  })
}
// 内部订单价格导出
export function mbExport(data) {
  return request({
    url: `/sip/order/export`,
    method: 'post',
    data: data,
    responseType: 'blob'
  })
}
// 内部订单价格失败下载
export function errDownload(data) {
  return request({
    url: `/sip/order/export/error`,
    method: 'post',
    data: data,
    responseType: 'blob'
  })
}